from setuptools import setup
from subprocess import check_output

with open('VERSION.txt', 'r') as content_file:
    version = content_file.read()

    setup(
        name='mnemosyne-client',
        version=version[1:],
        description='mnemosyne service grpc client library',
        url='http://github.com/piotrkowalczuk/mnemosyne',
        author='Piotr Kowalczuk',
        author_email='p.kowalczuk.priv@gmail.com',
        license='MIT',
        packages=['mnemosynerpc'],
        install_requires=[
            'protobuf',
            'grpcio',
        ],
        zip_safe=False,
        keywords=['mnemosyne', 'grpc', 'session', 'service', 'client'],
        download_url='https://github.com/piotrkowalczuk/mnemosyne/archive/%s.tar.gz' % version.rstrip(),
      )


# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: session.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='session.proto',
  package='mnemosynerpc',
  syntax='proto3',
  serialized_pb=_b('\n\rsession.proto\x12\x0cmnemosynerpc\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xea\x01\n\x07Session\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x12\n\nsubject_id\x18\x02 \x01(\t\x12\x16\n\x0esubject_client\x18\x03 \x01(\t\x12+\n\x03\x62\x61g\x18\x04 \x03(\x0b\x32\x1e.mnemosynerpc.Session.BagEntry\x12-\n\texpire_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rrefresh_token\x18\x06 \x01(\t\x1a*\n\x08\x42\x61gEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\"\n\nGetRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"5\n\x0bGetResponse\x12&\n\x07session\x18\x01 \x01(\x0b\x32\x15.mnemosynerpc.Session\"9\n\x0f\x43ontextResponse\x12&\n\x07session\x18\x01 \x01(\x0b\x32\x15.mnemosynerpc.Session\"\xa9\x01\n\x0bListRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\r\n\x05limit\x18\x02 \x01(\x03\x12\x32\n\x0e\x65xpire_at_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x65xpire_at_to\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rrefresh_token\x18\x05 \x01(\t\"7\n\x0cListResponse\x12\'\n\x08sessions\x18\x01 \x03(\x0b\x32\x15.mnemosynerpc.Session\"%\n\rExistsRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\" \n\x0e\x45xistsResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\"6\n\x0cStartRequest\x12&\n\x07session\x18\x01 \x01(\x0b\x32\x15.mnemosynerpc.Session\"7\n\rStartResponse\x12&\n\x07session\x18\x01 \x01(\x0b\x32\x15.mnemosynerpc.Session\"&\n\x0e\x41\x62\x61ndonRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"$\n\x0f\x41\x62\x61ndonResponse\x12\x11\n\tabandoned\x18\x01 \x01(\x08\"C\n\x0fSetValueRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"t\n\x10SetValueResponse\x12\x34\n\x03\x62\x61g\x18\x01 \x03(\x0b\x32\'.mnemosynerpc.SetValueResponse.BagEntry\x1a*\n\x08\x42\x61gEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x01\n\rDeleteRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x32\n\x0e\x65xpire_at_from\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x65xpire_at_to\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rrefresh_token\x18\x04 \x01(\t\x12\x12\n\nsubject_id\x18\x05 \x01(\t\"\x1f\n\x0e\x44\x65leteResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x32\xbc\x04\n\x0eSessionManager\x12\x42\n\x07\x43ontext\x12\x16.google.protobuf.Empty\x1a\x1d.mnemosynerpc.ContextResponse\"\x00\x12<\n\x03Get\x12\x18.mnemosynerpc.GetRequest\x1a\x19.mnemosynerpc.GetResponse\"\x00\x12?\n\x04List\x12\x19.mnemosynerpc.ListRequest\x1a\x1a.mnemosynerpc.ListResponse\"\x00\x12\x45\n\x06\x45xists\x12\x1b.mnemosynerpc.ExistsRequest\x1a\x1c.mnemosynerpc.ExistsResponse\"\x00\x12\x42\n\x05Start\x12\x1a.mnemosynerpc.StartRequest\x1a\x1b.mnemosynerpc.StartResponse\"\x00\x12H\n\x07\x41\x62\x61ndon\x12\x1c.mnemosynerpc.AbandonRequest\x1a\x1d.mnemosynerpc.AbandonResponse\"\x00\x12K\n\x08SetValue\x12\x1d.mnemosynerpc.SetValueRequest\x1a\x1e.mnemosynerpc.SetValueResponse\"\x00\x12\x45\n\x06\x44\x65lete\x12\x1b.mnemosynerpc.DeleteRequest\x1a\x1c.mnemosynerpc.DeleteResponse\"\x00\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_SESSION_BAGENTRY = _descriptor.Descriptor(
  name='BagEntry',
  full_name='mnemosynerpc.Session.BagEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mnemosynerpc.Session.BagEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='mnemosynerpc.Session.BagEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=328,
)

_SESSION = _descriptor.Descriptor(
  name='Session',
  full_name='mnemosynerpc.Session',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='mnemosynerpc.Session.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject_id', full_name='mnemosynerpc.Session.subject_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject_client', full_name='mnemosynerpc.Session.subject_client', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bag', full_name='mnemosynerpc.Session.bag', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expire_at', full_name='mnemosynerpc.Session.expire_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='mnemosynerpc.Session.refresh_token', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SESSION_BAGENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=328,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='mnemosynerpc.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='mnemosynerpc.GetRequest.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=364,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='mnemosynerpc.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='mnemosynerpc.GetResponse.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=419,
)


_CONTEXTRESPONSE = _descriptor.Descriptor(
  name='ContextResponse',
  full_name='mnemosynerpc.ContextResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='mnemosynerpc.ContextResponse.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=478,
)


_LISTREQUEST = _descriptor.Descriptor(
  name='ListRequest',
  full_name='mnemosynerpc.ListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='mnemosynerpc.ListRequest.offset', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='limit', full_name='mnemosynerpc.ListRequest.limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expire_at_from', full_name='mnemosynerpc.ListRequest.expire_at_from', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expire_at_to', full_name='mnemosynerpc.ListRequest.expire_at_to', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='mnemosynerpc.ListRequest.refresh_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=481,
  serialized_end=650,
)


_LISTRESPONSE = _descriptor.Descriptor(
  name='ListResponse',
  full_name='mnemosynerpc.ListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessions', full_name='mnemosynerpc.ListResponse.sessions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=707,
)


_EXISTSREQUEST = _descriptor.Descriptor(
  name='ExistsRequest',
  full_name='mnemosynerpc.ExistsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='mnemosynerpc.ExistsRequest.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=709,
  serialized_end=746,
)


_EXISTSRESPONSE = _descriptor.Descriptor(
  name='ExistsResponse',
  full_name='mnemosynerpc.ExistsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exists', full_name='mnemosynerpc.ExistsResponse.exists', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=748,
  serialized_end=780,
)


_STARTREQUEST = _descriptor.Descriptor(
  name='StartRequest',
  full_name='mnemosynerpc.StartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='mnemosynerpc.StartRequest.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=782,
  serialized_end=836,
)


_STARTRESPONSE = _descriptor.Descriptor(
  name='StartResponse',
  full_name='mnemosynerpc.StartResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='mnemosynerpc.StartResponse.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=838,
  serialized_end=893,
)


_ABANDONREQUEST = _descriptor.Descriptor(
  name='AbandonRequest',
  full_name='mnemosynerpc.AbandonRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='mnemosynerpc.AbandonRequest.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=895,
  serialized_end=933,
)


_ABANDONRESPONSE = _descriptor.Descriptor(
  name='AbandonResponse',
  full_name='mnemosynerpc.AbandonResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='abandoned', full_name='mnemosynerpc.AbandonResponse.abandoned', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=935,
  serialized_end=971,
)


_SETVALUEREQUEST = _descriptor.Descriptor(
  name='SetValueRequest',
  full_name='mnemosynerpc.SetValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='mnemosynerpc.SetValueRequest.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key', full_name='mnemosynerpc.SetValueRequest.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='mnemosynerpc.SetValueRequest.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=973,
  serialized_end=1040,
)


_SETVALUERESPONSE_BAGENTRY = _descriptor.Descriptor(
  name='BagEntry',
  full_name='mnemosynerpc.SetValueResponse.BagEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mnemosynerpc.SetValueResponse.BagEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='mnemosynerpc.SetValueResponse.BagEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=328,
)

_SETVALUERESPONSE = _descriptor.Descriptor(
  name='SetValueResponse',
  full_name='mnemosynerpc.SetValueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bag', full_name='mnemosynerpc.SetValueResponse.bag', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SETVALUERESPONSE_BAGENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1042,
  serialized_end=1158,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='mnemosynerpc.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='mnemosynerpc.DeleteRequest.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expire_at_from', full_name='mnemosynerpc.DeleteRequest.expire_at_from', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expire_at_to', full_name='mnemosynerpc.DeleteRequest.expire_at_to', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='mnemosynerpc.DeleteRequest.refresh_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject_id', full_name='mnemosynerpc.DeleteRequest.subject_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1161,
  serialized_end=1343,
)


_DELETERESPONSE = _descriptor.Descriptor(
  name='DeleteResponse',
  full_name='mnemosynerpc.DeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='mnemosynerpc.DeleteResponse.count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1345,
  serialized_end=1376,
)

_SESSION_BAGENTRY.containing_type = _SESSION
_SESSION.fields_by_name['bag'].message_type = _SESSION_BAGENTRY
_SESSION.fields_by_name['expire_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETRESPONSE.fields_by_name['session'].message_type = _SESSION
_CONTEXTRESPONSE.fields_by_name['session'].message_type = _SESSION
_LISTREQUEST.fields_by_name['expire_at_from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTREQUEST.fields_by_name['expire_at_to'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTRESPONSE.fields_by_name['sessions'].message_type = _SESSION
_STARTREQUEST.fields_by_name['session'].message_type = _SESSION
_STARTRESPONSE.fields_by_name['session'].message_type = _SESSION
_SETVALUERESPONSE_BAGENTRY.containing_type = _SETVALUERESPONSE
_SETVALUERESPONSE.fields_by_name['bag'].message_type = _SETVALUERESPONSE_BAGENTRY
_DELETEREQUEST.fields_by_name['expire_at_from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DELETEREQUEST.fields_by_name['expire_at_to'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Session'] = _SESSION
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.message_types_by_name['ContextResponse'] = _CONTEXTRESPONSE
DESCRIPTOR.message_types_by_name['ListRequest'] = _LISTREQUEST
DESCRIPTOR.message_types_by_name['ListResponse'] = _LISTRESPONSE
DESCRIPTOR.message_types_by_name['ExistsRequest'] = _EXISTSREQUEST
DESCRIPTOR.message_types_by_name['ExistsResponse'] = _EXISTSRESPONSE
DESCRIPTOR.message_types_by_name['StartRequest'] = _STARTREQUEST
DESCRIPTOR.message_types_by_name['StartResponse'] = _STARTRESPONSE
DESCRIPTOR.message_types_by_name['AbandonRequest'] = _ABANDONREQUEST
DESCRIPTOR.message_types_by_name['AbandonResponse'] = _ABANDONRESPONSE
DESCRIPTOR.message_types_by_name['SetValueRequest'] = _SETVALUEREQUEST
DESCRIPTOR.message_types_by_name['SetValueResponse'] = _SETVALUERESPONSE
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteResponse'] = _DELETERESPONSE

Session = _reflection.GeneratedProtocolMessageType('Session', (_message.Message,), dict(

  BagEntry = _reflection.GeneratedProtocolMessageType('BagEntry', (_message.Message,), dict(
    DESCRIPTOR = _SESSION_BAGENTRY,
    __module__ = 'session_pb2'
    # @@protoc_insertion_point(class_scope:mnemosynerpc.Session.BagEntry)
    ))
  ,
  DESCRIPTOR = _SESSION,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.Session)
  ))
_sym_db.RegisterMessage(Session)
_sym_db.RegisterMessage(Session.BagEntry)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRESPONSE,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.GetResponse)
  ))
_sym_db.RegisterMessage(GetResponse)

ContextResponse = _reflection.GeneratedProtocolMessageType('ContextResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONTEXTRESPONSE,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.ContextResponse)
  ))
_sym_db.RegisterMessage(ContextResponse)

ListRequest = _reflection.GeneratedProtocolMessageType('ListRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTREQUEST,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.ListRequest)
  ))
_sym_db.RegisterMessage(ListRequest)

ListResponse = _reflection.GeneratedProtocolMessageType('ListResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTRESPONSE,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.ListResponse)
  ))
_sym_db.RegisterMessage(ListResponse)

ExistsRequest = _reflection.GeneratedProtocolMessageType('ExistsRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXISTSREQUEST,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.ExistsRequest)
  ))
_sym_db.RegisterMessage(ExistsRequest)

ExistsResponse = _reflection.GeneratedProtocolMessageType('ExistsResponse', (_message.Message,), dict(
  DESCRIPTOR = _EXISTSRESPONSE,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.ExistsResponse)
  ))
_sym_db.RegisterMessage(ExistsResponse)

StartRequest = _reflection.GeneratedProtocolMessageType('StartRequest', (_message.Message,), dict(
  DESCRIPTOR = _STARTREQUEST,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.StartRequest)
  ))
_sym_db.RegisterMessage(StartRequest)

StartResponse = _reflection.GeneratedProtocolMessageType('StartResponse', (_message.Message,), dict(
  DESCRIPTOR = _STARTRESPONSE,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.StartResponse)
  ))
_sym_db.RegisterMessage(StartResponse)

AbandonRequest = _reflection.GeneratedProtocolMessageType('AbandonRequest', (_message.Message,), dict(
  DESCRIPTOR = _ABANDONREQUEST,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.AbandonRequest)
  ))
_sym_db.RegisterMessage(AbandonRequest)

AbandonResponse = _reflection.GeneratedProtocolMessageType('AbandonResponse', (_message.Message,), dict(
  DESCRIPTOR = _ABANDONRESPONSE,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.AbandonResponse)
  ))
_sym_db.RegisterMessage(AbandonResponse)

SetValueRequest = _reflection.GeneratedProtocolMessageType('SetValueRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETVALUEREQUEST,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.SetValueRequest)
  ))
_sym_db.RegisterMessage(SetValueRequest)

SetValueResponse = _reflection.GeneratedProtocolMessageType('SetValueResponse', (_message.Message,), dict(

  BagEntry = _reflection.GeneratedProtocolMessageType('BagEntry', (_message.Message,), dict(
    DESCRIPTOR = _SETVALUERESPONSE_BAGENTRY,
    __module__ = 'session_pb2'
    # @@protoc_insertion_point(class_scope:mnemosynerpc.SetValueResponse.BagEntry)
    ))
  ,
  DESCRIPTOR = _SETVALUERESPONSE,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.SetValueResponse)
  ))
_sym_db.RegisterMessage(SetValueResponse)
_sym_db.RegisterMessage(SetValueResponse.BagEntry)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteResponse = _reflection.GeneratedProtocolMessageType('DeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETERESPONSE,
  __module__ = 'session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.DeleteResponse)
  ))
_sym_db.RegisterMessage(DeleteResponse)


_SESSION_BAGENTRY.has_options = True
_SESSION_BAGENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_SETVALUERESPONSE_BAGENTRY.has_options = True
_SETVALUERESPONSE_BAGENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces


  class SessionManagerStub(object):

    def __init__(self, channel):
      """Constructor.

      Args:
        channel: A grpc.Channel.
      """
      self.Context = channel.unary_unary(
          '/mnemosynerpc.SessionManager/Context',
          request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
          response_deserializer=ContextResponse.FromString,
          )
      self.Get = channel.unary_unary(
          '/mnemosynerpc.SessionManager/Get',
          request_serializer=GetRequest.SerializeToString,
          response_deserializer=GetResponse.FromString,
          )
      self.List = channel.unary_unary(
          '/mnemosynerpc.SessionManager/List',
          request_serializer=ListRequest.SerializeToString,
          response_deserializer=ListResponse.FromString,
          )
      self.Exists = channel.unary_unary(
          '/mnemosynerpc.SessionManager/Exists',
          request_serializer=ExistsRequest.SerializeToString,
          response_deserializer=ExistsResponse.FromString,
          )
      self.Start = channel.unary_unary(
          '/mnemosynerpc.SessionManager/Start',
          request_serializer=StartRequest.SerializeToString,
          response_deserializer=StartResponse.FromString,
          )
      self.Abandon = channel.unary_unary(
          '/mnemosynerpc.SessionManager/Abandon',
          request_serializer=AbandonRequest.SerializeToString,
          response_deserializer=AbandonResponse.FromString,
          )
      self.SetValue = channel.unary_unary(
          '/mnemosynerpc.SessionManager/SetValue',
          request_serializer=SetValueRequest.SerializeToString,
          response_deserializer=SetValueResponse.FromString,
          )
      self.Delete = channel.unary_unary(
          '/mnemosynerpc.SessionManager/Delete',
          request_serializer=DeleteRequest.SerializeToString,
          response_deserializer=DeleteResponse.FromString,
          )


  class SessionManagerServicer(object):

    def Context(self, request, context):
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def Exists(self, request, context):
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def Start(self, request, context):
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def Abandon(self, request, context):
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def SetValue(self, request, context):
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')


  def add_SessionManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'Context': grpc.unary_unary_rpc_method_handler(
            servicer.Context,
            request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            response_serializer=ContextResponse.SerializeToString,
        ),
        'Get': grpc.unary_unary_rpc_method_handler(
            servicer.Get,
            request_deserializer=GetRequest.FromString,
            response_serializer=GetResponse.SerializeToString,
        ),
        'List': grpc.unary_unary_rpc_method_handler(
            servicer.List,
            request_deserializer=ListRequest.FromString,
            response_serializer=ListResponse.SerializeToString,
        ),
        'Exists': grpc.unary_unary_rpc_method_handler(
            servicer.Exists,
            request_deserializer=ExistsRequest.FromString,
            response_serializer=ExistsResponse.SerializeToString,
        ),
        'Start': grpc.unary_unary_rpc_method_handler(
            servicer.Start,
            request_deserializer=StartRequest.FromString,
            response_serializer=StartResponse.SerializeToString,
        ),
        'Abandon': grpc.unary_unary_rpc_method_handler(
            servicer.Abandon,
            request_deserializer=AbandonRequest.FromString,
            response_serializer=AbandonResponse.SerializeToString,
        ),
        'SetValue': grpc.unary_unary_rpc_method_handler(
            servicer.SetValue,
            request_deserializer=SetValueRequest.FromString,
            response_serializer=SetValueResponse.SerializeToString,
        ),
        'Delete': grpc.unary_unary_rpc_method_handler(
            servicer.Delete,
            request_deserializer=DeleteRequest.FromString,
            response_serializer=DeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'mnemosynerpc.SessionManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


  class BetaSessionManagerServicer(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    def Context(self, request, context):
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def Get(self, request, context):
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def List(self, request, context):
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def Exists(self, request, context):
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def Start(self, request, context):
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def Abandon(self, request, context):
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def SetValue(self, request, context):
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def Delete(self, request, context):
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)


  class BetaSessionManagerStub(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    def Context(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      raise NotImplementedError()
    Context.future = None
    def Get(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      raise NotImplementedError()
    Get.future = None
    def List(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      raise NotImplementedError()
    List.future = None
    def Exists(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      raise NotImplementedError()
    Exists.future = None
    def Start(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      raise NotImplementedError()
    Start.future = None
    def Abandon(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      raise NotImplementedError()
    Abandon.future = None
    def SetValue(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      raise NotImplementedError()
    SetValue.future = None
    def Delete(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      raise NotImplementedError()
    Delete.future = None


  def beta_create_SessionManager_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_deserializers = {
      ('mnemosynerpc.SessionManager', 'Abandon'): AbandonRequest.FromString,
      ('mnemosynerpc.SessionManager', 'Context'): google_dot_protobuf_dot_empty__pb2.Empty.FromString,
      ('mnemosynerpc.SessionManager', 'Delete'): DeleteRequest.FromString,
      ('mnemosynerpc.SessionManager', 'Exists'): ExistsRequest.FromString,
      ('mnemosynerpc.SessionManager', 'Get'): GetRequest.FromString,
      ('mnemosynerpc.SessionManager', 'List'): ListRequest.FromString,
      ('mnemosynerpc.SessionManager', 'SetValue'): SetValueRequest.FromString,
      ('mnemosynerpc.SessionManager', 'Start'): StartRequest.FromString,
    }
    response_serializers = {
      ('mnemosynerpc.SessionManager', 'Abandon'): AbandonResponse.SerializeToString,
      ('mnemosynerpc.SessionManager', 'Context'): ContextResponse.SerializeToString,
      ('mnemosynerpc.SessionManager', 'Delete'): DeleteResponse.SerializeToString,
      ('mnemosynerpc.SessionManager', 'Exists'): ExistsResponse.SerializeToString,
      ('mnemosynerpc.SessionManager', 'Get'): GetResponse.SerializeToString,
      ('mnemosynerpc.SessionManager', 'List'): ListResponse.SerializeToString,
      ('mnemosynerpc.SessionManager', 'SetValue'): SetValueResponse.SerializeToString,
      ('mnemosynerpc.SessionManager', 'Start'): StartResponse.SerializeToString,
    }
    method_implementations = {
      ('mnemosynerpc.SessionManager', 'Abandon'): face_utilities.unary_unary_inline(servicer.Abandon),
      ('mnemosynerpc.SessionManager', 'Context'): face_utilities.unary_unary_inline(servicer.Context),
      ('mnemosynerpc.SessionManager', 'Delete'): face_utilities.unary_unary_inline(servicer.Delete),
      ('mnemosynerpc.SessionManager', 'Exists'): face_utilities.unary_unary_inline(servicer.Exists),
      ('mnemosynerpc.SessionManager', 'Get'): face_utilities.unary_unary_inline(servicer.Get),
      ('mnemosynerpc.SessionManager', 'List'): face_utilities.unary_unary_inline(servicer.List),
      ('mnemosynerpc.SessionManager', 'SetValue'): face_utilities.unary_unary_inline(servicer.SetValue),
      ('mnemosynerpc.SessionManager', 'Start'): face_utilities.unary_unary_inline(servicer.Start),
    }
    server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
    return beta_implementations.server(method_implementations, options=server_options)


  def beta_create_SessionManager_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_serializers = {
      ('mnemosynerpc.SessionManager', 'Abandon'): AbandonRequest.SerializeToString,
      ('mnemosynerpc.SessionManager', 'Context'): google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ('mnemosynerpc.SessionManager', 'Delete'): DeleteRequest.SerializeToString,
      ('mnemosynerpc.SessionManager', 'Exists'): ExistsRequest.SerializeToString,
      ('mnemosynerpc.SessionManager', 'Get'): GetRequest.SerializeToString,
      ('mnemosynerpc.SessionManager', 'List'): ListRequest.SerializeToString,
      ('mnemosynerpc.SessionManager', 'SetValue'): SetValueRequest.SerializeToString,
      ('mnemosynerpc.SessionManager', 'Start'): StartRequest.SerializeToString,
    }
    response_deserializers = {
      ('mnemosynerpc.SessionManager', 'Abandon'): AbandonResponse.FromString,
      ('mnemosynerpc.SessionManager', 'Context'): ContextResponse.FromString,
      ('mnemosynerpc.SessionManager', 'Delete'): DeleteResponse.FromString,
      ('mnemosynerpc.SessionManager', 'Exists'): ExistsResponse.FromString,
      ('mnemosynerpc.SessionManager', 'Get'): GetResponse.FromString,
      ('mnemosynerpc.SessionManager', 'List'): ListResponse.FromString,
      ('mnemosynerpc.SessionManager', 'SetValue'): SetValueResponse.FromString,
      ('mnemosynerpc.SessionManager', 'Start'): StartResponse.FromString,
    }
    cardinalities = {
      'Abandon': cardinality.Cardinality.UNARY_UNARY,
      'Context': cardinality.Cardinality.UNARY_UNARY,
      'Delete': cardinality.Cardinality.UNARY_UNARY,
      'Exists': cardinality.Cardinality.UNARY_UNARY,
      'Get': cardinality.Cardinality.UNARY_UNARY,
      'List': cardinality.Cardinality.UNARY_UNARY,
      'SetValue': cardinality.Cardinality.UNARY_UNARY,
      'Start': cardinality.Cardinality.UNARY_UNARY,
    }
    stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
    return beta_implementations.dynamic_stub(channel, 'mnemosynerpc.SessionManager', cardinalities, options=stub_options)
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)
